@@ -2,19 +2,18 @@
 
 #    Copyright 2009, Brent Chiodo
 
-#    IMPORTANT, PLEASE READ CAREFULLY. THIS IS A LICENSE AGREEMENT
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, either version 3 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
 
-#    This SOFTWARE PRODUCT is protected by copyright laws and international copyright treaties, as well as other intellectual property laws and treaties. This SOFTWARE PRODUCT is licensed, not sold.
-
-#    End User License Agreement
-
-#    This End User License Agreement ("EULA") is a legal agreement between you (either an individual or a single entity) and Brent Chiodo with regard to the copyrighted Software (herein referred to as "SOFTWARE PRODUCT" or "SOFTWARE") provided with this EULA.  The SOFTWARE PRODUCT includes computer software, the associated media, any printed materials, and any "online" or electronic documentation. Use of any software and related documentation ("Software") provided to you by Brent Chiodo in whatever form or media, will constitute your acceptance of these terms, unless separate terms are provided by the software supplier, in which case certain additional or different terms may apply. If you do not agree with the terms of this EULA, do not download, install, copy or use the Software. By installing, copying or otherwise using the SOFTWARE PRODUCT, you agree to be bound by the terms of this EULA.
-
-#    1.  Brent Chiodo grants you the right to download, install and use the SOFTWARE PRODUCT as is. You agree that you may not modify, disassemble, or reverse engineer the SOFTWARE PRODUCT in any way.
-
-#    2.  You are granted the right to freely redistribute the SOFTWARE as long as it is in its original and unmodified form.
-
-#    3.  The Software is provided "AS IS" without warranty of any kind. Brent Chiodo and its suppliers disclaim and make no express or implied warranties and specifically disclaim the warranties of merchantability, fitness for a particular purpose and non-infringement of third-party rights. The entire risk as to the quality and performance of the Software is with you. Neither Brent Chiodo nor its suppliers warrant that the functions contained in the Software will meet your requirements or that the operation of the Software will be uninterrupted or error-free. Brent Chiodo IS NOT OBLIGATED TO PROVIDE ANY UPDATES TO THE SOFTWARE.
+#    You should have received a copy of the GNU General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 import gobject
@@ -388,19 +387,19 @@ class TouchSearchHomePlugin(hildondesktop.HomePluginItem):
       dialog.set_authors(["Brent Chiodo <bchiodo@gmail.com>"])
       dialog.set_logo(gtk.gdk.pixbuf_new_from_file("/usr/share/touchsearch/icon.png"))
       dialog.set_comments("All logos and trademarks are property of their respective owners and are used for informational purposes only.")
-      dialog.set_license("""IMPORTANT, PLEASE READ CAREFULLY. THIS IS A LICENSE AGREEMENT
+      dialog.set_license("""This program is free software: you can redistribute it and/or
+modify it under the terms of the GNU General Public License as 
+published by the Free Software Foundation, either version 3 of
+the License, or (at your option) any later version.
 
-This SOFTWARE PRODUCT is protected by copyright laws and international copyright treaties, as well as other intellectual property laws and treaties. This SOFTWARE PRODUCT is licensed, not sold.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied 
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the GNU General Public License for more details.
 
-End User License Agreement
-
-This End User License Agreement ("EULA") is a legal agreement between you (either an individual or a single entity) and Brent Chiodo with regard to the copyrighted Software (herein referred to as "SOFTWARE PRODUCT" or "SOFTWARE") provided with this EULA.  The SOFTWARE PRODUCT includes computer software, the associated media, any printed materials, and any "online" or electronic documentation. Use of any software and related documentation ("Software") provided to you by Brent Chiodo in whatever form or media, will constitute your acceptance of these terms, unless separate terms are provided by the software supplier, in which case certain additional or different terms may apply. If you do not agree with the terms of this EULA, do not download, install, copy or use the Software. By installing, copying or otherwise using the SOFTWARE PRODUCT, you agree to be bound by the terms of this EULA.
-
-1.  Brent Chiodo grants you the right to download, install and use the SOFTWARE PRODUCT as is. You agree that you may not modify, disassemble, or reverse engineer the SOFTWARE PRODUCT in any way.
-
-2.  You are granted the right to freely redistribute the SOFTWARE as long as it is in its original and unmodified form.
-
-3.  The Software is provided "AS IS" without warranty of any kind. Brent Chiodo and its suppliers disclaim and make no express or implied warranties and specifically disclaim the warranties of merchantability, fitness for a particular purpose and non-infringement of third-party rights. The entire risk as to the quality and performance of the Software is with you. Neither Brent Chiodo nor its suppliers warrant that the functions contained in the Software will meet your requirements or that the operation of the Software will be uninterrupted or error-free. Brent Chiodo IS NOT OBLIGATED TO PROVIDE ANY UPDATES TO THE SOFTWARE.""")
+You should have received a copy of the GNU General Public 
+License along with this program.  If not, see
+<http://www.gnu.org/licenses/>.""")
       dialog.set_wrap_license(True)
       dialog.show_all()
       dialog.run()
